pub struct OwnedRegion {
pub id: OwnedRegionId,
pub owner: PartitionId,
pub guest_base: GuestPhysAddr,
pub host_base: PhysAddr,
pub page_count: u32,
pub tier: Tier,
pub permissions: MemoryPermissions,
/* private fields */
}Expand description
An owned memory region entry in the region table.
Fields
id: OwnedRegionIdUnique region identifier.
owner: PartitionIdOwning partition.
guest_base: GuestPhysAddrGuest physical base address (page-aligned).
host_base: PhysAddrHost physical base address (page-aligned).
page_count: u32Number of pages in this region.
tier: TierCurrent memory tier.
permissions: MemoryPermissionsAccess permissions.
Implementations
Sourceimpl OwnedRegion
impl OwnedRegion
Sourcepub const fn size_bytes(&self) -> u64
pub const fn size_bytes(&self) -> u64
Return the size of this region in bytes.
Sourcepub const fn contains_guest(&self, addr: GuestPhysAddr) -> bool
pub const fn contains_guest(&self, addr: GuestPhysAddr) -> bool
Check if a guest physical address falls within this region.